"efa_loadings" table to matrix or a matrix to "efa_loadings"The loadings tables returned by efa_fit() are of class
c("efa_loadings", "LOADINGS"), which prevents applying functions on them.
This function changes their class to "matrix", and changes it back to
"efa_loadings" when done.
.change_class(x, cl = "matrix")A table with the loadings, of class either "efa_loadings" or
"matrix".
A table of class "matrix" or "efa_loadings".
A character vector with the class to change the table to. Should be
c("efa_loadings", "LOADINGS") or "matrix".
Andreas Soteriades