Learn R Programming

EFAtools (version 1.1.0)

.extract_list_object: Extract a list object by its name

Description

Consider a list of named sub-lists. This function extracts, for each sub-list, the sub-list element that is specified by the user. This function is useful for extracting results from efa_fit() for each imputation in efa_mi().

Usage

.extract_list_object(alist, object)

Value

A list of length \(m\), with each element containing the extracted object for the \(k\)th element (\(k = 1,..., m\)).

Arguments

alist

A list of sub-lists, typically a list of \(m\) objects of class "efa", where \(m\) is the number of imputations passed to efa_mi().

object

String of length 1. The name of the object to extract e.g. "h2" or "vars_accounted".

Author

Andreas Soteriades