Learn R Programming

EFAtools (version 0.8.0)

.hyperplane_count: Count near-zero loadings

Description

Hyperplane count is the number of loadings with absolute value smaller than a user-specified cutoff.

Usage

.hyperplane_count(L, cutoff = 0.15)

Value

A list with the total hyperplane count and counts by factor and item.

Arguments

L

Numeric loading matrix.

cutoff

Numeric scalar. Loadings with abs(L) < cutoff are counted as being in the hyperplane.