Learn R Programming

EFAtools (version 1.1.0)

.orthogonal_procrustes: Closed-form orthogonal Procrustes rotation

Description

Rotate A to the orthogonal target B by minimizing ||A %*% T - B||_F^2 subject to t(T) %*% T = I.

Usage

.orthogonal_procrustes(A, B)

Value

A list with the rotated loadings, orthogonal transformation matrix, target criterion value, and basic diagnostics.

Arguments

A

Numeric matrix to be rotated.

B

Numeric target matrix with the same dimensions as A.

References

Schoenemann, P. H. (1966). A generalized solution of the orthogonal Procrustes problem. Psychometrika, 31, 1-10.