Learn R Programming

EFAtools (version 0.7.1)

.stat_over_list: Calculate statistics for a list of matrices

Description

Calculate statistics for a list of matrices

Usage

.stat_over_list(alist, stat)

Value

A matrix with the aggregated results

Arguments

alist

A list of sub-lists, typically a list of \(m\) matrices from "EFA", where \(m\) is the number of imputations passed to EFA_POOLED.

stat

A function, e.g. mean or sd.

Author

Andreas Soteriades

Given a list of matrices, this function calculates user-supplied statistics (e.g. mean, median) over the matrices. This function is useful for averaging results from EFA (e.g. loadings) over all permutation runs in EFA_POOLED.