View source: R/EFAtools-superseded.R
| HULL | R Documentation |
HULL() has been superseded by efa_hull(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
HULL(
x,
N = NA,
n_fac_theor = NA,
method = c("PAF", "ULS", "ML"),
gof = c("CAF", "CFI", "RMSEA"),
eigen_type = c("SMC", "PCA", "EFA"),
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra"),
n_datasets = 1000,
percent = 95,
decision_rule = c("means", "percentile", "crawford"),
n_factors = 1,
...
)
x |
matrix or data.frame. Dataframe or matrix of raw data or matrix with correlations. |
N |
numeric. Number of cases in the data. This is passed to efa_parallel. Only has to be specified if x is a correlation matrix, otherwise it is determined based on the dimensions of x. |
n_fac_theor |
numeric. Theoretical number of factors to retain. One plus the larger of this number and the number of factors suggested by efa_parallel is used as the upper bound J of factors to extract in the Hull method. |
method |
character. The estimator to use; passed to |
gof |
character. The goodness of fit index to use. Either |
eigen_type |
character. On what the eigenvalues should be found in the
parallel analysis. Can be one of |
use |
character. Passed to |
cor_method |
character. One of |
n_datasets |
numeric. The number of datasets to simulate. Must be at
least 1. Default is 1000. This is passed to |
percent |
numeric. The percentile to take from the simulated eigenvalues.
Default is 95. This is passed to |
decision_rule |
character. Which rule to use to determine the number of
factors to retain. Default is |
n_factors |
numeric. Number of factors to extract if |
... |
Further arguments passed on to the |
An object of class efa_retention, identical to the value of
efa_hull(); see there for the components.
efa_hull()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.