View source: R/EFAtools-superseded.R
| SMT | R Documentation |
SMT() has been superseded by efa_smt(), which is the recommended interface
going forward. It remains available and unchanged so existing code keeps working.
SMT(
x,
N = NA,
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra")
)
x |
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations. |
N |
numeric. The number of observations. Needs only be specified if a correlation matrix is used. Must be larger than the number of variables. |
use |
character. Passed to |
cor_method |
character. One of |
An object of class efa_retention, identical to the value of
efa_smt(); see there for the components.
efa_smt()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.