dot-orthogonal_procrustes: Closed-form orthogonal Procrustes rotation

.orthogonal_procrustesR Documentation

Closed-form orthogonal Procrustes rotation

Description

Rotate A to the orthogonal target B by minimizing ⁠||A %*% T - B||_F^2⁠ subject to t(T) %*% T = I.

Usage

.orthogonal_procrustes(A, B)

Arguments

A

Numeric matrix to be rotated.

B

Numeric target matrix with the same dimensions as A.

Value

A list with the rotated loadings, orthogonal transformation matrix, target criterion value, and basic diagnostics.

References

Schoenemann, P. H. (1966). A generalized solution of the orthogonal Procrustes problem. Psychometrika, 31, 1-10.


EFAtools documentation built on Aug. 21, 2026, 5:16 p.m.