Learn R Programming

EFAtools (version 0.8.0)

plot.EFA_AVERAGE: Plot EFA_AVERAGE object

Description

Plot method showing a summarized output of the EFA_AVERAGE function

Usage

# S3 method for EFA_AVERAGE
plot(x, ...)

Value

A ggplot object showing, for each indicator and factor, the minimum, maximum, and average (mean or median) loading across the averaged solutions.

Arguments

x

list. An output from the EFA_AVERAGE function.

...

not used.

Examples

Run this code
if (FALSE) {
EFA_aver <- EFA_AVERAGE(test_models$baseline$cormat, n_factors = 3, N = 500)
plot(EFA_aver)
}

Run the code above in your browser using DataLab