"efa_loadings" table to matrix or a matrix to "efa_loadings"Convert an "efa_loadings" table to matrix or a matrix to "efa_loadings"
.change_class(x, cl = "matrix")A table with the loadings, of class either "efa_loadings" or
"matrix".
A table of class "matrix" or "efa_loadings".
A character vector with the class to change the table to. Should be
c("efa_loadings", "LOADINGS") or "matrix".
Andreas Soteriades
The loadings tables returned by efa_fit() are of class
c("efa_loadings", "LOADINGS"), which prevents applying functions on them.
This function allows to change their class to "matrix", and to change back
to "efa_loadings" when done.