Learn R Programming

EFAtools (version 0.8.0)

.change_class: Covert a "LOADINGS" table to matrix or a matrix to "LOADINGS"

Description

Covert a "LOADINGS" table to matrix or a matrix to "LOADINGS"

Usage

.change_class(x, cl = "matrix")

Value

A table with the loadings, of class either "LOADINGS" or "matrix".

Arguments

x

A table of class "matrix" or "LOADINGS".

cl

A string with the class to change the table to. Should be "LOADINGS" or "matrix".

Author

Andreas Soteriades

The loadings tables returned by EFA() are of class "LOADINGS", which prevents applying functions on them. This function allows to change their class to "matrix", and to change back to "LOADINGS" when done.