"LOADINGS" table to matrix or a matrix to "LOADINGS"Covert a "LOADINGS" table to matrix or a matrix to "LOADINGS"
.change_class(x, cl = "matrix")A table with the loadings, of class either "LOADINGS" or
"matrix".
A table of class "matrix" or "LOADINGS".
A string with the class to change the table to. Should be
"LOADINGS" or "matrix".
Andreas Soteriades
The loadings tables returned by EFA() are of class
"LOADINGS", which prevents applying functions on them. This function
allows to change their class to "matrix", and to change back to
"LOADINGS" when done.