Learn R Programming

EFAtools (version 0.8.0)

.extract_list_object: Extract a list object by its name

Description

Extract a list object by its name

Usage

.extract_list_object(alist, object)

Value

A list of length \(m\), with each element containing the extracted object for the \(k\)th element (\(k = 1,..., m\)).

Arguments

alist

A list of sub-lists, typically a list of \(m\) objects of class "EFA", where \(m\) is the number of imputations passed to EFA_POOLED().

object

String of length 1. The name of the object to extract e.g. "h2" or "vars_accounted".

Author

Andreas Soteriades

Consider a list of named sub-lists. This function extracts, for each sub-list, the sub-list element that is specified by the user. This function is useful for extracting results from EFA() for each permutation run in EFA_POOLED().