BARTLETT() has been superseded by efa_bartlett(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
Arguments
- x
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations.
- N
numeric. The number of observations. Needs only be specified if a correlation matrix is used.
- use
character. Passed to
stats::cor()if raw data is given as input. Default is "pairwise.complete.obs".- cor_method
character. Correlation computed from raw data:
"pearson","spearman", or"kendall"(passed tostats::cor()), or"poly"/"tetra"for polychoric / tetrachoric correlations of ordinal / binary data (a two-step estimator with no empty-cell continuity correction). Default is "pearson".
Value
A list of class c("efa_bartlett", "BARTLETT"), identical to the value
of efa_bartlett(); see there for the components.