View source: R/EFAtools-superseded.R
| BARTLETT | R Documentation |
BARTLETT() has been superseded by efa_bartlett(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
BARTLETT(
x,
N = NA,
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra")
)
x |
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations. |
N |
numeric. The number of observations. Needs only be specified if a correlation matrix is used. |
use |
character. The missing-data policy for raw data. Passed to
|
cor_method |
character. Correlation computed from raw data: |
A list of class c("efa_bartlett", "BARTLETT"), identical to the value
of efa_bartlett(); see there for the components.
efa_bartlett()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.