Learn R Programming

EFAtools (version 1.1.0)

GRiPS_raw: GRiPS_raw

Description

A data.frame containing responses to the General Risk Propensity Scale (GRiPS, Zhang, Highhouse & Nye, 2018) of 810 participants of Study 1 of Steiner and Frey (2020). The original data can be accessed via https://osf.io/kxp8t/.

Usage

GRiPS_raw

Arguments

Format

A data.frame with 810 rows (participants) and 8 columns, one per GRiPS item. Each item is a self-report indicator of general risk propensity, labelled by a keyword from the item:

fun

(numeric) - Risk-taking makes life more fun.

friends

(numeric) - Friends would describe the respondent as a risk taker.

enjoy

(numeric) - Enjoyment of taking risks.

hurt

(numeric) - Willingness to take a risk even if it might hurt.

part

(numeric) - Risk-taking as an important part of life.

commonly

(numeric) - Commonly takes risks.

chances

(numeric) - Belief in taking chances.

attracted

(numeric) - Attracted, rather than scared, by risk.