A data.frame containing responses to the General Risk Propensity Scale (GRiPS, Zhang, Highhouse & Nye, 2018) of 810 participants of Study 1 of Steiner and Frey (2020). The original data can be accessed via https://osf.io/kxp8t/.
GRiPS_rawA data.frame with 810 rows (participants) and 8 columns, one per GRiPS item. Each item is a self-report indicator of general risk propensity, labelled by a keyword from the item:
(numeric) - Risk-taking makes life more fun.
(numeric) - Friends would describe the respondent as a risk taker.
(numeric) - Enjoyment of taking risks.
(numeric) - Willingness to take a risk even if it might hurt.
(numeric) - Risk-taking as an important part of life.
(numeric) - Commonly takes risks.
(numeric) - Belief in taking chances.
(numeric) - Attracted, rather than scared, by risk.