Learn R Programming

EFAtools (version 0.8.0)

KMO: Kaiser-Meyer-Olkin criterion

Description

This function computes the Kaiser-Meyer-Olkin (KMO) criterion overall and for each variable in a correlation matrix. The KMO represents the degree to which each observed variable is predicted by the other variables in the dataset and with this indicates the suitability for factor analysis.

Usage

KMO(
  x,
  use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
    "na.or.complete"),
  cor_method = c("pearson", "spearman", "kendall", "poly", "tetra")
)

Value

A list containing

KMO

Overall KMO.

KMO_i

KMO for each variable.

settings

A list of the settings used.

Arguments

x

data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations.

use

character. Passed to stats::cor() if raw data is given as input. Default is "pairwise.complete.obs".

cor_method

character. Correlation computed from raw data: "pearson", "spearman", or "kendall" (passed to stats::cor()), or "poly" / "tetra" for polychoric / tetrachoric correlations of ordinal / binary data (a two-step estimator with no empty-cell continuity correction). Default is "pearson".

Details

Kaiser (1970) proposed this index, originally called measure of sampling adequacy (MSA), that indicates how near the inverted correlation matrix \(R^{-1}\) is to a diagonal matrix \(S\) to determine a given correlation matrix's (\(R\)) suitability for factor analysis. The index is $$KMO = \frac{\sum_{i \neq j} r_{ij}^2}{\sum_{i \neq j} r_{ij}^2 + \sum_{i \neq j} q_{ij}^2}$$ with \(Q = SR^{-1}S\) and S = \((diag R^{-1})^{-1/2}\) where \(\sum_{i \neq j} r_{ij}^2\) is the sum of squares of the off-diagonal elements of \(R\) and \(\sum_{i \neq j} q_{ij}^2\) is the sum of squares of the off-diagonal elements of \(Q\) (see also Cureton & D'Agostino, 1983).

So KMO varies between 0 and 1, with larger values indicating higher suitability for factor analysis. Kaiser and Rice (1974) suggest that KMO should at least exceed .50 for a correlation matrix to be suitable for factor analysis.

This function was heavily influenced by the psych::KMO() function.

See also BARTLETT() for another test of suitability for factor analysis.

The KMO function can also be called together with the BARTLETT() function and with factor retention criteria in the N_FACTORS() function.

See Also

BARTLETT() for another measure to determine suitability for factor analysis.

N_FACTORS() as a wrapper function for this function, BARTLETT() and several factor retention criteria.

Examples

Run this code
KMO(test_models$baseline$cormat)

Run the code above in your browser using DataLab