MAP() has been superseded by efa_map(), which is the recommended interface
going forward. It remains available and unchanged so existing code keeps working.
MAP(
x,
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra")
)An object of class efa_retention, identical to the value of
efa_map(); see there for the components.
A numeric matrix or data.frame. Can be either (a) a correlation matrix, or
(b) raw data (rows = observations, columns = variables) from which correlations are computed.
Character string specifying the treatment of missing values when computing correlations.
Passed to stats::cor(). Defaults to "pairwise.complete.obs".
Character string specifying the correlation coefficient to be computed if raw
data are supplied. One of "pearson", "spearman", or "kendall" (passed to
stats::cor()), or "poly" / "tetra" for polychoric / tetrachoric correlations
of ordinal / binary data (a two-step estimator). Defaults to "pearson".
efa_map()