NEST() has been superseded by efa_nest(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
Arguments
- x
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations.
- N
numeric. The number of observations. Only needed if x is a correlation matrix.
- alpha
numeric. The alpha level to use (i.e., 1-alpha percentile of eigenvalues is used for reference values).
- use
character. Passed to
stats::cor()if raw data is given as input. Default is "pairwise.complete.obs".- cor_method
character. One of
"pearson","spearman", or"kendall", passed tostats::cor()."poly"and"tetra"are not supported becauseNESTcompares the data against simulated continuous reference data. Default is"pearson".- n_datasets
numeric. The number of datasets to simulate. Default is 1000.
- ...
Further arguments passed on to the
efa_fit()fits. For example,estimator, to change the estimator (PAF is default), or one of the estimation tuning knobs (type,init_comm,criterion,criterion_type,max_iter,abs_eigen,start_method), which are repacked into anestimate_control()object so that they tune the fits exactly as they always did.
Value
An object of class efa_retention, identical to the value of
efa_nest(); see there for the components.