View source: R/EFAtools-superseded.R
| NEST | R Documentation |
NEST() has been superseded by efa_nest(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
NEST(
x,
N = NA,
alpha = 0.05,
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra"),
n_datasets = 1000,
...
)
x |
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations. |
N |
numeric. The number of observations. Only needed if x is a correlation matrix. Must be larger than the number of variables. |
alpha |
numeric. The alpha level to use (i.e., 1-alpha percentile of eigenvalues is used for reference values). |
use |
character. Passed to |
cor_method |
character. One of |
n_datasets |
numeric. The number of datasets to simulate. Default is 1000. |
... |
Further arguments passed on to the |
An object of class efa_retention, identical to the value of
efa_nest(); see there for the components.
efa_nest()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.