| RiskDimensions | R Documentation |
A list containing the bivariate correlations (cormat) of the 9 dimensions on which participants in Fischhoff et al. (1978) rated different activities and technologies as well as the sample size (N). This was then analyzed together with ratings of the risks and benefits of these activities and technologies.
RiskDimensions
A list of 2 with elements "cormat" (9 x 9 matrix of bivariate correlations) and "N" (scalar). The correlation matrix contains the following risk dimensions:
(numeric) - Voluntariness of exposure to the risk.
(numeric) - Immediacy of the risk's effect.
(numeric) - How well the risk is known to those exposed to it.
(numeric) - How well the risk is known to science.
(numeric) - Controllability of the risk.
(numeric) - Newness of the risk.
(numeric) - Whether the risk is chronic rather than catastrophic.
(numeric) - Whether the risk is common rather than dreaded.
(numeric) - Severity of the consequences.
Fischhoff, B, Slovic, P, Lichtenstein, S, Read, S, and Combs, B. (1978). How safe is safe enough? A psychometric study of attitudes towards technological risks and benefits. Policy Sciences, 9, 127-152. doi: 10.1007/BF00143739
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.