A list containing the bivariate correlations (cormat) of the 9 dimensions on which participants in Fischhoff et al. (1978) rated different activities and technologies as well as the sample size (N). This was then analyzed together with ratings of the risks and benefits of these activities and technologies.
RiskDimensionsA list of 2 with elements "cormat" (9 x 9 matrix of bivariate correlations) and "N" (scalar). The correlation matrix contains the following risk dimensions:
(numeric) - Voluntariness of exposure to the risk.
(numeric) - Immediacy of the risk's effect.
(numeric) - How well the risk is known to those exposed to it.
(numeric) - How well the risk is known to science.
(numeric) - Controllability of the risk.
(numeric) - Newness of the risk.
(numeric) - Whether the risk is chronic rather than catastrophic.
(numeric) - Whether the risk is common rather than dreaded.
(numeric) - Severity of the consequences.