View source: R/EFAtools-superseded.R
| SL | R Documentation |
SL() has been superseded by efa_schmid_leiman(), which is the recommended
interface going forward. It remains available and unchanged so existing code
keeps working.
SL(
x,
Phi = NULL,
type = c("EFAtools", "psych", "SPSS", "none"),
method = c("PAF", "ML", "ULS", "MINRES"),
g_name = "g",
...
)
x |
object of class |
Phi |
matrix. A matrix of factor intercorrelations from an oblique factor
solution. Only needs to be specified if a pattern matrix is entered directly
into |
type |
character. One of "EFAtools" (default), "psych", "SPSS", or "none". This is
used to control the procedure of the second-order factor analysis. In
|
method |
character. The estimator for the second-order factor analysis; passed to
|
g_name |
character. The name of the general factor. This needs only be
specified if |
... |
Further arguments passed on to the second-order |
A list of class c("efa_schmid_leiman", "SL"), identical to the value
of efa_schmid_leiman(); see there for the components.
efa_schmid_leiman()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.