Learn R Programming

EFAtools (version 1.1.0)

UPPS_raw: UPPS_raw

Description

A dataframe containing responses to the UPPS personality scale (Whiteside & Lynam, 2005) of 645 participants of Study 2 of Steiner and Frey (2020). Each column are the ratings to one of 45 items to assess urgency, premeditation, perseverance, and sensation seeking. The original data can be accessed via https://osf.io/kxp8t/.

Usage

UPPS_raw

Arguments

Format

A data.frame with 645 rows (participants) and 45 columns, named by a subscale prefix and item number, covering the four UPPS subscales:

perseverance_1 to perseverance_10

(numeric) - Perseverance-subscale items.

premeditation_1 to premeditation_11

(numeric) - Premeditation-subscale items.

ss_1 to ss_12

(numeric) - Sensation-seeking-subscale items.

urgency_1 to urgency_12

(numeric) - Urgency-subscale items.