dot-change_class: Convert an '"efa_loadings"' table to matrix or a matrix to...

.change_classR Documentation

Convert an "efa_loadings" table to matrix or a matrix to "efa_loadings"

Description

The loadings tables returned by efa_fit() are of class c("efa_loadings", "LOADINGS"), which prevents applying functions on them. This function changes their class to "matrix", and changes it back to "efa_loadings" when done.

Usage

.change_class(x, cl = "matrix")

Arguments

x

A table of class "matrix" or "efa_loadings".

cl

A character vector with the class to change the table to. Should be c("efa_loadings", "LOADINGS") or "matrix".

Value

A table with the loadings, of class either "efa_loadings" or "matrix".

Author(s)

Andreas Soteriades


EFAtools documentation built on Aug. 21, 2026, 5:16 p.m.