| .change_class | R Documentation |
"efa_loadings" table to matrix or a matrix to "efa_loadings"The loadings tables returned by efa_fit() are of class
c("efa_loadings", "LOADINGS"), which prevents applying functions on them.
This function changes their class to "matrix", and changes it back to
"efa_loadings" when done.
.change_class(x, cl = "matrix")
x |
A table of class |
cl |
A character vector with the class to change the table to. Should be
|
A table with the loadings, of class either "efa_loadings" or
"matrix".
Andreas Soteriades
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.