| .orthogonal_procrustes | R Documentation |
Rotate A to the orthogonal target B by minimizing
||A %*% T - B||_F^2 subject to t(T) %*% T = I.
.orthogonal_procrustes(A, B)
A |
Numeric matrix to be rotated. |
B |
Numeric target matrix with the same dimensions as |
A list with the rotated loadings, orthogonal transformation matrix, target criterion value, and basic diagnostics.
Schoenemann, P. H. (1966). A generalized solution of the orthogonal Procrustes problem. Psychometrika, 31, 1-10.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.