Probably the most popular factor retention criterion. Kaiser and Guttman suggested to retain as many factors as there are sample eigenvalues greater than 1. This is why the criterion is also known as eigenvalues-greater-than-one rule.
Auerswald, M., & Moshagen, M. (2019). How to determine the number of factors to retain in exploratory factor analysis: A comparison of extraction methods under realistic conditions. Psychological Methods, 24(4), 468–491. https://doi.org/10.1037/met0000200
Guttman, L. (1954). Some necessary conditions for common-factor analysis. Psychometrika, 19, 149 –161. http://dx.doi.org/10.1007/BF02289162
Kaiser, H. F. (1960). The application of electronic computers to factor analysis. Educational and Psychological Measurement, 20, 141–151. http://dx.doi.org/10.1177/001316446002000116
Zwick, W. R., & Velicer, W. F. (1986). Comparison of five rules for determining the number of components to retain. Psychological Bulletin, 99, 432–442. http://dx.doi.org/10.1037/0033-2909.99.3.432
Arguments
- x
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations.
- eigen_type
character. On what the eigenvalues should be found. Can be either "PCA", "SMC", or "EFA", or some combination of them. If using "PCA", the diagonal values of the correlation matrices are left to be 1. If using "SMC", the diagonal of the correlation matrices is replaced by the squared multiple correlations (SMCs) of the indicators. If using "EFA", eigenvalues are found on the correlation matrices with the final communalities of an exploratory factor analysis solution (default is principal axis factoring extracting 1 factor) as diagonal.
- use
character. Passed to
stats::cor()if raw data is given as input. Default is "pairwise.complete.obs".- cor_method
character. Correlation computed from raw data:
"pearson","spearman", or"kendall"(passed tostats::cor()), or"poly"/"tetra"for polychoric / tetrachoric correlations of ordinal / binary data (a two-step estimator with no empty-cell continuity correction). Default is "pearson".- n_factors
numeric. Number of factors to extract if "EFA" is included in
eigen_type. Default is 1.- estimate_control
an
estimate_control()object with the estimation settings for theefa_fit()fit that provides the communalities when"EFA"is included ineigen_type.NULL(default) uses theefa_fit()defaults. The fit is unrotated, so no rotation settings apply.- ...
Additional arguments passed to
efa_fit(). For example,estimator, to change the estimator (PAF is default). The estimation tuning knobs are not passed here; they live inestimate_control.
Value
An object of class efa_retention (see print.efa_retention() and
plot.efa_retention() for the print and plot methods). Its main fields are:
- n_factors
A named numeric vector with the suggested number of factors for each requested eigenvalue type (
"PCA","SMC", and/or"EFA").- results
A list with one record per eigenvalue type, each holding the eigenvalues and the retained solution used for printing and plotting.
- settings
A list of the settings used.
Details
Originally, the Kaiser-Guttman criterion was intended for the use
with principal components, hence with eigenvalues derived from the original
correlation matrix. This can be done here by setting eigen_type to
"PCA". However, it is well-known that this criterion is often inaccurate and
that it tends to overestimate the number of factors, especially for unidimensional
or orthogonal factor structures (e.g., Zwick & Velicer, 1986).
The criterion's inaccuracy in these cases is somewhat addressed if it is
applied on the correlation matrix with communalities in the diagonal, either
initial communalities estimated from SMCs (done setting eigen_type to
"SMC") or final communality estimates from an EFA (done setting eigen_type
to "EFA"; see Auerswald & Moshagen, 2019). However, although this variant
of the KGC is more accurate in some cases compared to the traditional KGC, it
is at the same time less accurate than the PCA-variant in other cases, and it
is still often less accurate than other factor retention methods, for
example parallel analysis (efa_parallel()), the Hull method
efa_hull(), or sequential \(chi^2\) model tests (efa_smt();
see Auerswald & Moshagen, 2019).
The efa_kgc function can also be called together with other factor
retention criteria in the efa_retain() function.
See also
efa_retain() as a wrapper function for this and the other factor
retention criteria.
Other factor retention criteria:
efa_cd(),
efa_ekc(),
efa_hull(),
efa_map(),
efa_nest(),
efa_parallel(),
efa_retain(),
efa_scree(),
efa_smt()
Examples
efa_kgc(test_models$baseline$cormat, eigen_type = c("PCA", "SMC"))
#> ── Kaiser-Guttman criterion ────────────────────────────────────────────────────
#>
#> • PCA eigenvalues: 3
#> • SMC eigenvalues: 1