| efa_kgc | R Documentation |
Probably the most popular factor retention criterion. Kaiser and Guttman suggested to retain as many factors as there are sample eigenvalues greater than 1. This is why the criterion is also known as eigenvalues-greater-than-one rule.
efa_kgc(
x,
eigen_type = c("PCA", "SMC", "EFA"),
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra"),
n_factors = 1,
estimate_control = NULL,
...
)
x |
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations. |
eigen_type |
character. On what the eigenvalues should be found. Can be
either "PCA", "SMC", or "EFA", or some combination of them. If using "PCA",
the diagonal values of the correlation matrices are left to be 1. If using
"SMC", the diagonal of the
correlation matrices is replaced by the squared multiple correlations (SMCs)
of the indicators. If using "EFA", eigenvalues are found on the correlation
matrices with the final communalities of an exploratory factor analysis
solution (default is principal axis factoring extracting 1 factor) as
diagonal. Default is |
use |
character. Passed to |
cor_method |
character. Correlation computed from raw data: |
n_factors |
numeric. Number of factors to extract if "EFA" is included in
|
estimate_control |
an |
... |
Additional arguments passed to |
Originally, the Kaiser-Guttman criterion was intended for the use
with principal components, hence with eigenvalues derived from the original
correlation matrix. This can be done here by setting eigen_type to
"PCA". However, it is well-known that this criterion is often inaccurate and
that it tends to overestimate the number of factors, especially for unidimensional
or orthogonal factor structures (e.g., Zwick & Velicer, 1986).
The criterion's inaccuracy in these cases is somewhat addressed if it is
applied on the correlation matrix with communalities in the diagonal, either
initial communalities estimated from SMCs (done setting eigen_type to
"SMC") or final communality estimates from an EFA (done setting eigen_type
to "EFA"; see Auerswald & Moshagen, 2019). However, although this variant
of the KGC is more accurate in some cases compared to the traditional KGC, it
is at the same time less accurate than the PCA-variant in other cases, and it
is still often less accurate than several of the other criteria available here,
such as parallel analysis (efa_parallel()), the Hull method (efa_hull()),
the empirical Kaiser criterion (efa_ekc()), or sequential chi^2 model
tests (efa_smt(); see Auerswald & Moshagen, 2019). Which criteria are
informative depends on the data at hand, so rather than substituting one for
another, run several of them together and compare their suggestions.
The efa_kgc function can also be called together with other factor
retention criteria in the efa_retain() function.
An object of class efa_retention (see print.efa_retention() and
plot.efa_retention() for the print and plot methods). Its main fields are:
n_factors |
A named numeric vector with the suggested number of factors
for each requested eigenvalue type ( |
results |
A list with one record per eigenvalue type, each holding the eigenvalues and the retained solution used for printing and plotting. |
settings |
A list of the settings used. |
Auerswald, M., & Moshagen, M. (2019). How to determine the number of factors to retain in exploratory factor analysis: A comparison of extraction methods under realistic conditions. Psychological Methods, 24(4), 468–491. https://doi.org/10.1037/met0000200
Guttman, L. (1954). Some necessary conditions for common-factor analysis. Psychometrika, 19, 149 –161. https://doi.org/10.1007/BF02289162
Kaiser, H. F. (1960). The application of electronic computers to factor analysis. Educational and Psychological Measurement, 20, 141–151. https://doi.org/10.1177/001316446002000116
Zwick, W. R., & Velicer, W. F. (1986). Comparison of five rules for determining the number of components to retain. Psychological Bulletin, 99, 432–442. https://doi.org/10.1037/0033-2909.99.3.432
efa_retain() as a wrapper function for this and the other factor
retention criteria.
Other factor retention criteria:
efa_cd(),
efa_ekc(),
efa_hull(),
efa_map(),
efa_nest(),
efa_parallel(),
efa_retain(),
efa_scree(),
efa_smt()
efa_kgc(test_models$baseline$cormat, eigen_type = c("PCA", "SMC"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.