| efa_kmo | R Documentation |
This function computes the Kaiser-Meyer-Olkin (KMO) criterion overall and for each variable in a correlation matrix. The KMO represents the degree to which each observed variable is predicted by the other variables in the dataset and with this indicates the suitability for factor analysis.
efa_kmo(
x,
use = c("pairwise.complete.obs", "all.obs", "complete.obs", "everything",
"na.or.complete"),
cor_method = c("pearson", "spearman", "kendall", "poly", "tetra")
)
x |
data.frame or matrix. Dataframe or matrix of raw data or matrix with correlations. |
use |
character. The missing-data policy for raw data. Passed to
|
cor_method |
character. Correlation computed from raw data: |
Kaiser (1970) proposed this index, originally called measure of
sampling adequacy (MSA), that indicates how near the inverted correlation
matrix R^{-1} is to a diagonal matrix to determine a given
correlation matrix's (R) suitability for factor analysis.
The index is
KMO = \frac{\sum_{i \neq j} r_{ij}^2}{\sum_{i \neq j} r_{ij}^2 + \sum_{i \neq j} q_{ij}^2}
with Q = SR^{-1}S and S = (diag R^{-1})^{-1/2} where
\sum_{i \neq j} r_{ij}^2 is the sum of squares of the off-diagonal
elements of R and \sum_{i \neq j} q_{ij}^2 is the sum of squares of
the off-diagonal elements of Q (see also Cureton & D'Agostino, 1983).
So KMO varies between 0 and 1, with larger values indicating higher suitability for factor analysis. Kaiser and Rice (1974) suggest that KMO should at least exceed .50 for a correlation matrix to be suitable for factor analysis.
This function was heavily influenced by the psych::KMO()
function.
See also efa_bartlett() for another test of suitability for factor
analysis.
The efa_kmo function can also be called together with the
efa_bartlett() function and with factor retention criteria in the
efa_retain() function.
A list containing
KMO |
Overall KMO. |
KMO_i |
KMO for each variable. |
settings |
A list of the settings used. |
Kaiser, H. F. (1970). A second generation little jiffy. Psychometrika, 35, 401-415.
Kaiser, H. F. & Rice, J. (1974). Little jiffy, mark IV. Educational and Psychological Measurement, 34, 111-117.
Cureton, E. E. & D'Agostino, R. B. (1983). Factor analysis: An applied approach. Hillsdale, N.J.: Lawrence Erlbaum Associates, Inc.
efa_bartlett() for another measure to determine
suitability for factor analysis.
efa_retain() as a wrapper function for this function,
efa_bartlett() and several factor retention criteria.
Other factor analysis suitability:
efa_bartlett(),
efa_screen(),
print.efa_screen()
efa_kmo(test_models$baseline$cormat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.