Learn R Programming

EFAtools (version 1.0.0)

plot.efa_average: Plot efa_average object

Description

Plot method showing a summarized output of the efa_average() function

Usage

# S3 method for efa_average
plot(x, ...)

Value

A ggplot object showing, for each indicator and factor, the minimum, maximum, and average (mean or median) loading across the averaged solutions.

Arguments

x

list. An output from the efa_average() function.

...

not used.

Examples

Run this code
# \donttest{
EFA_aver <- efa_average(test_models$baseline$cormat, n_factors = 3, N = 500)
plot(EFA_aver)
# }

Run the code above in your browser using DataLab