powered by
Plot method showing a summarized output of the efa_average() function
efa_average()
# S3 method for efa_average plot(x, ...)
A ggplot object showing, for each indicator and factor, the minimum, maximum, and average (mean or median) loading across the averaged solutions.
list. An output from the efa_average() function.
not used.
# \donttest{ EFA_aver <- efa_average(test_models$baseline$cormat, n_factors = 3, N = 500) plot(EFA_aver) # }
Run the code above in your browser using DataLab